.. _pyboard_tutorial:

MicroPython tutorial for the pyboard
====================================

This tutorial is intended to get you started with your pyboard.
All you need is a pyboard and a micro-USB cable to connect it to
your PC.  If it is your first time, it is recommended to follow
the tutorial through in the order below.

.. toctree::
   :maxdepth: 1
   :numbered:

   intro.rst
   script.rst
   repl.rst
   leds.rst
   switch.rst
   accel.rst
   reset.rst
   usb_mouse.rst
   timer.rst
   assembler.rst
   power_ctrl.rst

Tutorials requiring extra components
------------------------------------

.. toctree::
   :maxdepth: 1
   :numbered:

   servo.rst
   fading_led.rst
   lcd_skin.rst
   amp_skin.rst
   lcd160cr_skin.rst

Tips, tricks and useful things to know
--------------------------------------

.. toctree::
   :maxdepth: 1
   :numbered:

   debounce.rst
   pass_through.rst
